Extra Developer Tools
---------------------

These are miscellaneous additional tools and definitions, which may be
useful for developers.

.. toctree::
   :maxdepth: 1
   :caption: Modules:

   structs
   util
